/****************************************************************************

    Module
        w32cbm.h
  
    Description
        InCode Bitmap Compiler Include File
  
    Author(s)
        ss (Sven Spitzmacher <sspitzmacher@bitsmart.com>)

    Revision history
 
    970423 ss
        Initial Version

    970424 ss
        Removed ByteCheck(tm) Debugging Parts
        Added standard header
        First Public Release


    Copyright notice
        The copyright to the program code herein belongs to the authors.
        It may not be used for commercial and/or shareware products
        without prior written permission. For licensing information
        contact me at 'sspitzmacher@bitsmart.com'
 
****************************************************************************/

#ifndef __W32CBM_H__
#define __W32CBM_H__

#ifdef __cplusplus
extern "C" {
#endif


/****************************************************************************
 * InCode_BlitCompiledBitmap                                                *
 *    Blit a compiled bitmap into the destination buffer                    *
 ****************************************************************************
 * Returns:             -- nothing --                                       *
 *                                                                          *
 * Parameters:                                                              *
 * 1) char *src         Pointer to the compiled bitmap's data               *
 * 2) short x           X-Position in the destination buffer                *
 * 3) short y           Y-Position in the destination buffer                *
 * 4) short destw       Width of the destination buffer in byte             *
 * 5) char *dest        Pointer to the destination buffer                   *
 ****************************************************************************/
extern void InCode_BlitCompiledBitmap(char *, short, short, short, char*);

/****************************************************************************
 * InCode_CompileBitmap                                                     *
 *    Compile a bitmap                                                      *
 ****************************************************************************
 * Returns: (char*)     Pointer to compiled bitmap or NULL if error         *
 *                                                                          *
 * Parameters:                                                              *
 * 1) short w           Width of the bitmap                                 *
 * 2) short h           Height of the bitmap                                *
 * 3) short destw       Width of the destination buffer                     *
 * 4) char *bitmap      Pointer to the bitmap                               *
 ****************************************************************************/
char *InCode_CompileBitmap(short w, short h, short destw, char *bitmap);

/****************************************************************************
 * InCode_InitCompiler                                                      *
 *    Initialize the bitmap compiler                                        *
 ****************************************************************************
 * Returns:             -- nothing --                                       *
 *                                                                          *
 * Parameters:          -- none --                                          *
 ****************************************************************************/
void InCode_InitCompiler(void);


#ifdef __cplusplus
}
#endif

#endif
